@@ -2,6 +2,7 @@
 
 import requests
 
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import ActionQueue
 
 from .abstract_command import AbstractCommand
@@ -26,11 +27,13 @@ class ActionQueueProcessCommand(AbstractCommand):
         ----------
         request: ActionQueue
             The action queue to process.
+        headers: dict[str, str]
+            Request headers
         """
 
         requests.post(
-            url=f"{self.config.endpoint}/v1/world/queue",
+            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/world/queue",
             data=request.json(by_alias=True),
             headers=headers,
-            timeout=self.config.timeout,
+            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
