@@ -2,6 +2,7 @@
 import requests
 from requests import Response
 
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import UserActive
 
 from ..abstract_command import AbstractCommand
@@ -26,6 +27,8 @@ class UserActiveGetCommand(AbstractCommand):
         ----------
         user_guid: str
             The user guid to look up.
+        headers: dict[str, str]
+            Request headers
 
         Returns
         -------
@@ -34,6 +37,8 @@ class UserActiveGetCommand(AbstractCommand):
         """
 
         response: Response = requests.get(
-            url=f"{self.config.endpoint}/v1/user/{user_guid}/active", headers=headers, timeout=self.config.timeout
+            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/active",
+            headers=headers,
+            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
         return UserActive.parse_obj(response.json())
