@@ -2,6 +2,7 @@
 import requests
 from requests import Response
 
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import UserActive
 
 from ..abstract_command import AbstractCommand
@@ -28,6 +29,8 @@ class UserActiveSetCommand(AbstractCommand):
             The user guid to target.
         request: UserActive
             The active state to set the user to.
+        headers: dict[str, str]
+            Request headers
 
         Returns
         -------
@@ -36,10 +39,10 @@ class UserActiveSetCommand(AbstractCommand):
         """
 
         response: Response = requests.post(
-            url=f"{self.config.endpoint}/v1/user/{user_guid}/active",
+            url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/active",
             # TODO: In the future when this is the user object we will need to white list (or black list properties).
             data=request.json(by_alias=True, exclude={"state"}),
             headers=headers,
-            timeout=self.config.timeout,
+            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
         return UserActive.parse_obj(response.json())
